@@ -1,10 +1,6 @@
-import os
-import re
 import sys
-import colorama
-from colorama import Fore, Style
+from QuickProject import *
 
-COLORAMA_INIT_FLAG = True
 if sys.platform.startswith('win'):
     is_win = True
     dir_char = '\\'
@@ -14,7 +10,6 @@ else:
 work_dir = os.getcwd()
 work_project = work_dir.split(dir_char)[-1]
 work_dir += dir_char
-
 lang_template = {
     'cpp': """#include <iostream>
 using namespace std;
@@ -42,27 +37,6 @@ int main(int argc, char **argv) {
 }
 
 
-def basic_string_replace(ss):
-    global COLORAMA_INIT_FLAG
-    if COLORAMA_INIT_FLAG:
-        colorama.init()
-        COLORAMA_INIT_FLAG = False
-    ss = ss.split('\n')
-    ret = ''
-    for i in ss:
-        if '[' in i:
-            replace_list = re.findall('\[(.*?)\]', i)
-            split_list = re.split('\[.*?\]', i)
-            for p in range(len(split_list)):
-                ret += Fore.CYAN + split_list[p] + Style.RESET_ALL
-                if p < len(replace_list):
-                    ret += Fore.RED + '[' + Fore.YELLOW + replace_list[p] + Fore.RED + ']' + Style.RESET_ALL
-        else:
-            ret += i
-        ret += '\n'
-    return ret
-
-
 def remove(path):
     import shutil
     if os.path.exists(path):
@@ -72,29 +46,14 @@ def remove(path):
             os.remove(path)
 
 
-def get_config():
-    config = {}
-    try:
-        with open('project_configure.csv', 'r') as f:
-            for row in f.readlines():
-                row = row.split(',')
-                config[row[0]] = [i.strip() for i in row[1:]]
-            for i in config:
-                if i != 'compile_tool':
-                    config[i] = config[i][0]
-    except IOError:
-        exit("No file named: project_configure.csv\n May you need run:\"Qpro -init\" first!")
-    return config
-
-
-def scp_init(server_target, ct=False):
+def scp_init(server_target: list, ct=False):
     if server_target:
-        server, target = get_server_target(server_target)
+        server, target, port = get_server_target(server_target)
         user, ip = server.split('@')
         if ct:
-            st = os.system('scp -r %s %s' % (work_project, user + '@\\[' + ip + '\\]:' + target))
+            st = SshProtocol.post_folder(user, ip, target, port, '')
         else:
-            st = os.system('scp -r * %s' % user + '@\\[' + ip + '\\]:' + target)
+            st = SshProtocol.post_all_in_folder(user, ip, target, port)
         if st:
             exit("upload project failed!")
 
@@ -159,7 +118,7 @@ def create():
             ['executable_filename', execute],
             ['input_file', 'dist' + dir_char + 'input.txt' if lang[-1] else ''],
             ['template_root', 'template' + dir_char if lang[-1] else ''],
-            ['server_target', server_target]
+            ['server_target', server_target, '22' if server_target else '']
         ]
         with open(project_name + dir_char + 'project_configure.csv', 'w') as f:
             for row in info:
@@ -171,7 +130,7 @@ def create():
                 main_cont = f.read()
             with open(project_name + dir_char + 'template' + dir_char + 'main', 'w') as f:
                 f.write(main_cont)
-        scp_init(server_target, True)
+        scp_init(info[-1][1:] if server_target else None, True)
 
 
 def scp():
@@ -184,12 +143,12 @@ def scp():
             exit("%s is not in this Qpro project!" % path)
         if not os.path.exists(path):
             exit('No such file named: ' + path)
-        server, target = get_server_target()
+        server, target, port = get_server_target()
         user, ip = server.split('@')
         if os.path.isdir(path):
-            os.system('scp -r %s %s' % (path, user + '@\\[' + ip + '\\]:' + target + path))
+            SshProtocol.post_folder(user, ip, target, port, path)
         else:
-            os.system('scp %s %s' % (path, user + '@\\[' + ip + '\\]:' + target + path))
+            SshProtocol.post_file(user, ip, target, port, path)
 
 
 def get():
@@ -200,9 +159,9 @@ def get():
     else:
         if not os.path.abspath(path).startswith(work_dir):
             exit("%s is not in this Qpro project!" % path)
-        server, target = get_server_target()
+        server, target, port = get_server_target()
         user, ip = server.split('@')
-        os.system('scp -r %s %s' % (user + '@\\[' + ip + '\\]:' + target + path, path))
+        SshProtocol.get_file_or_folder(user, ip, target, port, path)
 
 
 def adjust():
@@ -221,7 +180,7 @@ def adjust():
     all_dt = {}
     for i, v in enumerate(config):
         tk.Label(win, text='%12s' % key_to_name[v]).grid(row=i, column=0)
-        if v == 'compile_tool':
+        if v == 'compile_tool' or v == 'server_target':
             stringvar1 = tk.Variable()
             stringvar1.set(config[v][0])
             stringvar2 = tk.Variable()
@@ -240,14 +199,21 @@ def adjust():
             if dt == 'compile_tool':
                 config[dt] = [all_dt[dt][0].get(), all_dt[dt][1].get()]
             elif dt == 'server_target':
-                config[dt] = all_dt[dt].get()
-                if config[dt]:
-                    if ':' in config[dt] and not config[dt].endswith('/') and not config[dt].endswith(':'):
-                        config[dt] += '/'
-                    elif ':' not in config[dt]:
-                        print('Not a legal server target!\n'
-                              'You can run "Qpro -adjust" to adjust target\n'
-                              'and run "Qpro -scp-init" to upload project.')
+                config[dt] = [all_dt[dt][0].get(), all_dt[dt][1].get()]
+                if config[dt][0]:
+                    try:
+                        if ':' in config[dt][0]:
+                            if config[dt][0].count(':') not in [1, 8]:
+                                raise Exception('%s: not a legal server target')
+                            if not (config[dt][0].endswith('/') and config[dt][0].endswith(':')):
+                                config[dt][0] += '/'
+                        else:
+                            raise Exception('%s: not a legal server target')
+                    except Exception as e:
+                        print(repr(e))
+                        print('Legal server target:\n'
+                              '  addr: <username>@<ipv4 | ipv6 | domain>:</path/to/project/>'
+                              '  port: <ssh port>, default 22')
             else:
                 config[dt] = all_dt[dt].get()
         if not config['template_root'].endswith(dir_char):
@@ -255,7 +221,7 @@ def adjust():
         win.destroy()
         with open('project_configure.csv', 'w') as file:
             for line in config:
-                if line == 'compile_tool':
+                if line == 'compile_tool' or line == 'server_target':
                     file.write('%s,%s\n' % (line, ','.join(config[line])))
                 else:
                     file.write('%s,%s\n' % (line, config[line]))
@@ -317,7 +283,7 @@ def pro_init():
             ['executable_filename', execute],
             ['input_file', 'dist' + dir_char + 'input.txt' if langs[id_lang - 1] != 'empty' else ''],
             ['template_root', 'template' + dir_char if langs[id_lang - 1] != 'empty' else ''],
-            ['server_target', server_target]
+            ['server_target', server_target, '22' if server_target else '']
         ]
     else:
         with open("CMakeLists.txt", 'r') as f:
@@ -346,13 +312,13 @@ def pro_init():
             ['executable_filename', project_name],
             ['input_file', default_input],
             ['template_root', 'template' + dir_char],
-            ['server_target', server_target]
+            ['server_target', server_target, '22' if server_target else '']
         ]
     with open('project_configure.csv', 'w') as f:
         for row in info:
             f.write(','.join(row) + '\n')
     if id_lang >= 0 and langs[id_lang - 1] == 'empty':
-        scp_init(server_target)
+        scp_init(info[-1][1:] if server_target else None)
         exit(0)
     with open(info[3][-1], 'w') as f:
         f.write('edit this file to make input')
@@ -365,32 +331,19 @@ def pro_init():
             f.write(main_cont)
     except Exception as e:
         print("make backup failed with error: %s, you need backup code by yourself!" % e)
-    scp_init(server_target)
-
-
-def get_server_target(st=None):
-    if not st:
-        ls = get_config()['server_target'].split(':')
-    else:
-        ls = st.split(':')
-    if len(ls) > 2:
-        server = ':'.join(ls[:8])
-        target = ':'.join(ls[8:])
-    else:
-        server, target = ls
-    return server, target
+    scp_init(info[-1][1:] if server_target else None)
 
 
 def ssh():
-    server, target = get_server_target()
-    os.system("ssh -t %s 'cd %s ; exec $SHELL -l'" % (server, target))
+    server, target, port = get_server_target()
+    os.system("ssh -p %s -t %s 'cd %s ; exec $SHELL -l'" % (port, server, target))
 
 
 def delete_all():
     config = get_config()
     if ':' in config['server_target']:
-        server, target = get_server_target()
-        st = os.system("ssh %s 'rm -rf %s'" % (server, target))
+        server, target, port = get_server_target()
+        st = os.system("ssh -p %s %s 'rm -rf %s'" % (port, server, target))
         if st:
             return
     remove(os.getcwd())
@@ -410,8 +363,8 @@ def delete():
         path = path.strip('.' + dir_char)
         path = path.strip(dir_char)
         if ':' in config['server_target']:
-            server, target = get_server_target()
-            st = os.system("ssh %s 'rm -rf %s'" % (server, target + path))
+            server, target, port = get_server_target()
+            st = os.system("ssh -p %s %s 'rm -rf %s'" % (port, server, target + path))
             if st:
                 return
         remove(path)
@@ -427,8 +380,8 @@ def tele_ls():
         path = path.strip('.' + dir_char)
         path = path.strip(dir_char)
     if ':' in config['server_target']:
-        server, target = get_server_target()
-        os.system("ssh %s 'ls %s'" % (server, target + path))
+        server, target, port = get_server_target()
+        os.system("ssh -p %s %s 'ls %s'" % (port, server, target + path))
 
 
 func = {
@@ -467,7 +420,7 @@ def main():
     elif sys.argv[1] in func:
         func[sys.argv[1]]()
     elif sys.argv[1] == '-scp-init':
-        scp_init(get_config()['server_target'])
+        scp_init(get_config()['server_target'][1:])
     elif '-init' not in sys.argv:
         exit('wrong usage! Run "Qpro -h" for help!')
     elif not os.path.exists('project_configure.csv'):
