@@ -54,7 +54,8 @@ def get_config(exit_if_failed: bool = True):
     try:
         with open('project_configure.csv', 'r') as f:
             for row in f.readlines():
-                row = row.split(',')
+                row = row.replace('\,', '--QPRO-IS-SPLIT--')
+                row = [i.replace('--QPRO-IS-SPLIT--', ',') for i in row.split(',')]
                 config[row[0]] = [i.strip() for i in row[1:]]
             for i in config:
                 if i != 'compile_tool' and i != 'server_target':
